@@ -51,7 +51,7 @@ pk_backend_get_author (PkBackend *backend)
 }
 
 static void
-pk_alpm_logcb (alpm_loglevel_t level, const gchar *format, va_list args)
+pk_alpm_logcb (void *ctx, alpm_loglevel_t level, const gchar *format, va_list args)
 {
 	g_autofree gchar *output = NULL;
 
@@ -86,13 +86,14 @@ pk_alpm_initialize (PkBackend *backend, GError **error)
 		return FALSE;
 	}
 
-	alpm_option_set_logcb (priv->alpm, pk_alpm_logcb);
+	priv->alpm_check = NULL;
+	alpm_option_set_logcb (priv->alpm, pk_alpm_logcb, NULL);
 
 	priv->localdb = alpm_get_localdb (priv->alpm);
 	if (priv->localdb == NULL) {
-		alpm_errno_t errno = alpm_errno (priv->alpm);
-		g_set_error (error, PK_ALPM_ERROR, errno, "[%s]: %s", "local",
-			     alpm_strerror (errno));
+		alpm_errno_t alpm_err = alpm_errno (priv->alpm);
+		g_set_error (error, PK_ALPM_ERROR, alpm_err, "[%s]: %s", "local",
+			     alpm_strerror (alpm_err));
 	}
 
 	return TRUE;
