@@ -263,6 +263,7 @@ static const PkEnumMatch enum_group[] = {
 	{PK_GROUP_ENUM_DESKTOP_GNOME,		"desktop-gnome"},
 	{PK_GROUP_ENUM_DESKTOP_KDE,		"desktop-kde"},
 	{PK_GROUP_ENUM_DESKTOP_XFCE,		"desktop-xfce"},
+	{PK_GROUP_ENUM_DESKTOP_DDE,		"desktop-dde"},
 	{PK_GROUP_ENUM_DESKTOP_OTHER,		"desktop-other"},
 	{PK_GROUP_ENUM_PUBLISHING,		"publishing"},
 	{PK_GROUP_ENUM_SERVERS,			"servers"},
@@ -321,6 +322,7 @@ static const PkEnumMatch enum_info[] = {
 	{PK_INFO_ENUM_DECOMPRESSING,		"decompressing"},
 	{PK_INFO_ENUM_UNTRUSTED,			"untrusted"},
 	{PK_INFO_ENUM_TRUSTED,				"trusted"},
+	{PK_INFO_ENUM_CRITICAL,			"critical"},
 	{0, NULL}
 };
 
