@@ -195,7 +195,7 @@ pk_progress_bar_draw_pulse_bar (PkProgressBar *self)
 		self->priv->pulse_state.position = 1;
 		self->priv->pulse_state.move_forward = TRUE;
 		self->priv->timer_id = g_timeout_add (PK_PROGRESS_BAR_PULSE_TIMEOUT,
-						      (GSourceFunc) pk_progress_bar_pulse_bar, self);
+						      G_SOURCE_FUNC (pk_progress_bar_pulse_bar), self);
 		g_source_set_name_by_id (self->priv->timer_id, "[PkProgressBar] pulse");
 	}
 }
