@@ -794,7 +794,7 @@ pk_task_user_accepted (PkTask *task, guint request)
 	}
 
 	idle_source = g_idle_source_new ();
-	g_source_set_callback (idle_source, (GSourceFunc) pk_task_user_accepted_idle_cb, state, NULL);
+	g_source_set_callback (idle_source, G_SOURCE_FUNC (pk_task_user_accepted_idle_cb), state, NULL);
 	g_source_set_name (idle_source, "[PkTask] user-accept");
 	g_source_attach (idle_source, g_main_context_get_thread_default ());
 	return TRUE;
@@ -821,7 +821,7 @@ pk_task_user_declined_idle_cb (PkTaskState *state)
 	g_debug ("declined request %i", state->request);
 	g_set_error (&error,
 			     PK_CLIENT_ERROR,
-			     PK_CLIENT_ERROR_FAILED, "user declined interaction");
+			     PK_CLIENT_ERROR_DECLINED_INTERACTION, "user declined interaction");
 	pk_task_generic_state_finish (state, error);
 	return FALSE;
 }
@@ -851,7 +851,7 @@ pk_task_user_declined (PkTask *task, guint request)
 	}
 
 	idle_source = g_idle_source_new ();
-	g_source_set_callback (idle_source, (GSourceFunc) pk_task_user_declined_idle_cb, state, NULL);
+	g_source_set_callback (idle_source, G_SOURCE_FUNC (pk_task_user_declined_idle_cb), state, NULL);
 	g_source_set_name (idle_source, "[PkTask] user-accept");
 	g_source_attach (idle_source, g_main_context_get_thread_default ());
 	return TRUE;
@@ -2581,7 +2581,7 @@ pk_task_class_init (PkTaskClass *klass)
 	 */
 	pspec = g_param_spec_boolean ("simulate", NULL, NULL,
 				      TRUE,
-				      G_PARAM_READWRITE);
+				      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_SIMULATE, pspec);
 
 	/**
@@ -2593,7 +2593,7 @@ pk_task_class_init (PkTaskClass *klass)
 	 */
 	pspec = g_param_spec_boolean ("only-download", NULL, NULL,
 				      FALSE,
-				      G_PARAM_READWRITE);
+				      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_ONLY_PREPARE, pspec);
 
 	/**
@@ -2605,7 +2605,7 @@ pk_task_class_init (PkTaskClass *klass)
 	 */
 	pspec = g_param_spec_boolean ("only-trusted", NULL, NULL,
 				      TRUE,
-				      G_PARAM_READWRITE);
+				      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_ONLY_TRUSTED, pspec);
 
 	/**
@@ -2617,7 +2617,7 @@ pk_task_class_init (PkTaskClass *klass)
 	 */
 	pspec = g_param_spec_boolean ("allow-reinstall", NULL, NULL,
 				      FALSE,
-				      G_PARAM_READWRITE);
+				      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_ALLOW_REINSTALL, pspec);
 
 	/**
@@ -2629,7 +2629,7 @@ pk_task_class_init (PkTaskClass *klass)
 	 */
 	pspec = g_param_spec_boolean ("allow-downgrade", NULL, NULL,
 				      FALSE,
-				      G_PARAM_READWRITE);
+				      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_ALLOW_DOWNGRADE, pspec);
 
 	g_type_class_add_private (klass, sizeof (PkTaskPrivate));
